@@ -78,7 +78,7 @@ class CogEnvDecoder:
         collision_info = self._CollCondtion(obs)#collision times and continuous collision time
         final_obs = [img, self_pos, enemy_pos, self_info, goal1, goal2, goal3, goal4, goal5]
         judge_result = [score, flag_ach, enemy_act, enemy_info, dmg, time, collision_info]
-        return final_obs, reward, done, info, judge_result
+        return final_obs, reward, done, [info, judge_result]
     
     def render(self, mode):
         return self._env.render(mode)
